from pathlib import Path

from model_server.util import autonumber_new_directory, get_matching_files, loop_workflow
from extensions.chaeo.ecotaxa import write_ecotaxa_tsv_chunked_subdirectories
from extensions.chaeo.params import ZMaskExportParams
from extensions.chaeo.workflows import infer_object_map_from_zstack
from extensions.ilastik.models import IlastikPixelClassifierModel


if __name__ == '__main__':
    sample_id = '20231028-porto-PA'
    root = Path('c:/Users/rhodes/projects/proj0012-trec-handoff/owncloud-sync/TREC-HD/Images/')
    where_czi = (root / 'TREC_STOP_26_Porto/231028_automic/20231028-134649_successfulrun/Selection').__str__()
    where_output = autonumber_new_directory(
        'c:/Users/rhodes/projects/proj0011-plankton-seg/exp0023/output',
        'batch-output'
    )

    px_ilp = Path('c:/Users/rhodes/projects/proj0011-plankton-seg/exp0017/pxAF405_dim8bit.ilp').__str__()

    export_params = {
        'pixel_probabilities': True,
        # 'patches_3d': {},
        'patches_2d_for_training': {
            # 'draw_bounding_box': False,
        },
        'patches_2d_for_annotation': {
            'draw_bounding_box': True,
            'rgb_overlay_channels': (1, None, None),
            'rgb_overlay_weights': (0.2, 1.0, 1.0),
        },
        'annotated_z_stack': {
            'draw_label': True
        }
    }
    ZMaskExportParams(**export_params)

    params = {
        'pxmap_threshold': 0.25,
        'pxmap_foreground_channel': 0,
        'segmentation_channel': 0,
        'zmask_zindex': None,
        'patches_channel': 2,
        'zmask_type': 'boxes',
        'zmask_filters': {'area': (1e3, 1e8)},
        'zmask_expand_box_by': (128, 3),
        'zmask_clip': 0.01,
        # 'export_pixel_probabilities': True,
        # 'export_2d_patches_for_training': True,
        # 'draw_bounding_box_on_2d_patch': True,
        # 'export_2d_patches_for_annotation': True,
        # 'export_3d_patches': False,
        # 'export_annotated_zstack': True,
        # 'export_patch_masks': True,

        # 'rgb_overlay_channels': (1, None, None),
        # 'rgb_overlay_weights': (0.2, 1.0, 1.0),
        # 'draw_label_on_zstack': True,
        'exports': ZMaskExportParams(**export_params),
    }

    input_files = get_matching_files(where_czi, 'czi', coord_filter={})

    loop_workflow(
        input_files,
        where_output,
        infer_object_map_from_zstack,
        [IlastikPixelClassifierModel(params={'project_file': Path(px_ilp)})],
        params,
        catch_and_continue=False,
        chunk_size=25,
    )

    write_ecotaxa_tsv_chunked_subdirectories(
        where_output,
        'workflow_data.csv',
        sample_id=sample_id,
        scope_id='EMBL-MS-Zeiss-LSM900'
    )

    print('Finished')